******
Casslr
******

Casslr is a library to use Scalr with Cassandra. It is a local agent running alongside Cassandra, which can be
queried by Cassandra to provide Seed information when Cassandra launches.
